
.. _sardana-getting-started:

===============
Getting started
===============

The next chapters describe the necessary steps to get started with sardana,
from installation to having a running system on your machine.

.. toctree::
   :maxdepth: 1

   Obtaining and installing <installing>
   Running the server <running_server>
   Running the client <running_cli>
   
